import {
  select,
  csv,
  pie,
  arc,
  scaleOrdinal,
  schemeCategory10,
  axisBottom,
  axisLeft,
} from 'd3';

const svg = select('svg');
const width = +svg.attr('width');
const height = +svg.attr('height');

// dollars
const numberFormat = (number) =>
  Math.abs(Number(number)) + ' $';

const render = (data) => {
  const pieData = pie()
    .sort(null)
    .value((d) => d.basic_cost)(data);
  const colors = scaleOrdinal(schemeCategory10);
  const segments = arc()
    .innerRadius(0)
    .outerRadius(200)
    .padAngle(0)
    .padRadius(0);

  const sections = svg
    .append('g')
    .attr('transform', `translate(250,250)`)
    .selectAll('path')
    .data(pieData);
  sections
    .enter()
    .append('path')
    .attr('d', segments)
    .attr('fill', (d) => colors(d.data.basic_cost))
    .on('mouseover', (d) => console.log(d.data.basic_cost));

  const legends = svg
    .append('g')
    .attr('transform', 'translate(500,100)')
    .selectAll('.legends')
    .data(pieData);
  const legend = legends
    .enter()
    .append('g')
    .classed('legends', true)
    .attr('transform', (d, i) => {
      return `translate(0,${(i + 1) * 30})`;
    });

  legend
    .append('rect')
    .attr('width', 22)
    .attr('height', 25)
    .attr('fill', (d) => colors(d.data.basic_cost));
  legend
    .append('text')
    .attr('x', 28)
    .attr('y', 18)
    .attr('class', 'legend_text')
    .text((d) => d.data.country);
  legend
    .append('text')
    .attr('x', 260)
    .attr('y', 20)
    .attr('class', 'legend_value')
    .text((d) => numberFormat(d.data.basic_cost));

  // X-axis label
  svg
    .append('text')
    .attr(
      'transform',
      'translate(' + width / 2 + ' ,' + (height - 20) + ')',
    )
    .style('text-anchor', 'middle')
    .text('Country');

  // Y-axis label
  svg
    .append('text')
    .attr('transform', 'rotate(-90)')
    .attr('y', 20)
    .attr('x', 0 - height / 2)
    .attr('dy', '1em')
    .style('text-anchor', 'middle')
    .text('Basic Cost ($)');
};

const csvUrl =
  'https://raw.githubusercontent.com/harshitavairagade/Activity7_Datasets/main/netflix.csv';

csv(csvUrl).then((csvData) => {
  csvData.forEach((d) => {
    d.basic_cost = +d.basic_cost; // Parse as number
  });
  csvData.sort(
    (data1, data2) => data2.basic_cost - data1.basic_cost,
  );
  if (csvData) {
    render(csvData.slice(0, 10));
  }
});
